HostControllerRequest

Enum HostControllerRequest 

pub enum HostControllerRequest {
    GetHosts {
        responder: HostControllerGetHostsResponder,
    },
    SetDiscoverability {
        payload: HostControllerSetDiscoverabilityRequest,
        responder: HostControllerSetDiscoverabilityResponder,
    },
    SetLocalName {
        payload: HostControllerSetLocalNameRequest,
        responder: HostControllerSetLocalNameResponder,
    },
    StartPairingDelegate {
        payload: HostControllerStartPairingDelegateRequest,
        responder: HostControllerStartPairingDelegateResponder,
    },
    StopPairingDelegate {
        responder: HostControllerStopPairingDelegateResponder,
    },
    SetDeviceClass {
        payload: HostControllerSetDeviceClassRequest,
        responder: HostControllerSetDeviceClassResponder,
    },
#[non_exhaustive]
_UnknownMethod { ordinal: u64, control_handle: HostControllerControlHandle, method_type: MethodType, }, }

Variants



GetHosts

Get all known hosts.

  • error Returns INTERNAL if the operation failed (check logs).


SetDiscoverability

Set discoverability state.

  • error Returns INTERNAL if the operation failed (check logs).


SetLocalName

Set the active host’s local name.

  • request name Name to assign to the host.
  • error Returns INTERNAL if the operation failed (check logs).


StartPairingDelegate

Start a pairing delegate to respond to pairing procedures. Only one pairing delegate can be set at a time host-wide. Calling this while a delegate started by this method is already active will drop and overwrite the existing delegate. If this is called while a delegate started through other means is active, the new delegate will be closed immediately. Closing a pairing delegate after it is set aborts all ongoing pairing procedures without accepting and unsets the delegate.

If no pairing delegate is set, all pairings will be rejected even if the peer connection was initiated by the host.

  • error Returns INTERNAL if the operation failed (check logs).


StopPairingDelegate

Stop a pairing delegate previously started by [StartPairingDelegate]. This will abort all ongoing pairing procedures without accepting and unsets the delegate.

This method can only stop a delegate started by [StartPairingDelegate], and will not stop a delegate started through other means.

  • error Returns INTERNAL if the operation failed (check logs).


SetDeviceClass

Set the active host’s device class.

  • error Returns INTERNAL if the operation failed (check logs).


#[non_exhaustive]
_UnknownMethod

An interaction was received which does not match any known method.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
ordinal: u64

Ordinal of the method that was called.

method_type: MethodType

Implementations