pub struct CentralControllerMarker;Trait Implementations
Sourceimpl Clone for CentralControllerMarker
impl Clone for CentralControllerMarker
Sourcefn clone(&self) -> CentralControllerMarker
fn clone(&self) -> CentralControllerMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CentralControllerMarker
impl Debug for CentralControllerMarker
Sourceimpl DiscoverableProtocolMarker for CentralControllerMarker
impl DiscoverableProtocolMarker for CentralControllerMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
Sourceimpl Hash for CentralControllerMarker
impl Hash for CentralControllerMarker
Sourceimpl Ord for CentralControllerMarker
impl Ord for CentralControllerMarker
Sourcefn cmp(&self, other: &CentralControllerMarker) -> Ordering
fn cmp(&self, other: &CentralControllerMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for CentralControllerMarker
impl PartialEq for CentralControllerMarker
Sourcefn eq(&self, other: &CentralControllerMarker) -> bool
fn eq(&self, other: &CentralControllerMarker) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for CentralControllerMarker
impl PartialOrd for CentralControllerMarker
Sourceimpl ProtocolMarker for CentralControllerMarker
impl ProtocolMarker for CentralControllerMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.bluetooth.affordances.CentralController"
const DEBUG_NAME: &'static str = "fuchsia.bluetooth.affordances.CentralController"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = CentralControllerProxy
type Proxy = CentralControllerProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = CentralControllerRequestStream
type RequestStream = CentralControllerRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = CentralControllerSynchronousProxy
type SynchronousProxy = CentralControllerSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for CentralControllerMarker
impl Eq for CentralControllerMarker
impl StructuralPartialEq for CentralControllerMarker