pub struct GattClientControllerMarker;Trait Implementations
Sourceimpl Clone for GattClientControllerMarker
impl Clone for GattClientControllerMarker
Sourcefn clone(&self) -> GattClientControllerMarker
fn clone(&self) -> GattClientControllerMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GattClientControllerMarker
impl Debug for GattClientControllerMarker
Sourceimpl DiscoverableProtocolMarker for GattClientControllerMarker
impl DiscoverableProtocolMarker for GattClientControllerMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
Sourceimpl Hash for GattClientControllerMarker
impl Hash for GattClientControllerMarker
Sourceimpl Ord for GattClientControllerMarker
impl Ord for GattClientControllerMarker
Sourcefn cmp(&self, other: &GattClientControllerMarker) -> Ordering
fn cmp(&self, other: &GattClientControllerMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for GattClientControllerMarker
impl PartialEq for GattClientControllerMarker
Sourcefn eq(&self, other: &GattClientControllerMarker) -> bool
fn eq(&self, other: &GattClientControllerMarker) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for GattClientControllerMarker
impl PartialOrd for GattClientControllerMarker
Sourceimpl ProtocolMarker for GattClientControllerMarker
impl ProtocolMarker for GattClientControllerMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.bluetooth.affordances.GattClientController"
const DEBUG_NAME: &'static str = "fuchsia.bluetooth.affordances.GattClientController"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = GattClientControllerProxy
type Proxy = GattClientControllerProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = GattClientControllerRequestStream
type RequestStream = GattClientControllerRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = GattClientControllerSynchronousProxy
type SynchronousProxy = GattClientControllerSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for GattClientControllerMarker
impl Eq for GattClientControllerMarker
impl StructuralPartialEq for GattClientControllerMarker