pub struct HostControllerMarker;Trait Implementations
Sourceimpl Clone for HostControllerMarker
impl Clone for HostControllerMarker
Sourcefn clone(&self) -> HostControllerMarker
fn clone(&self) -> HostControllerMarker
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HostControllerMarker
impl Debug for HostControllerMarker
Sourceimpl DiscoverableProtocolMarker for HostControllerMarker
impl DiscoverableProtocolMarker for HostControllerMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
Sourceimpl Hash for HostControllerMarker
impl Hash for HostControllerMarker
Sourceimpl Ord for HostControllerMarker
impl Ord for HostControllerMarker
Sourcefn cmp(&self, other: &HostControllerMarker) -> Ordering
fn cmp(&self, other: &HostControllerMarker) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for HostControllerMarker
impl PartialEq for HostControllerMarker
Sourceimpl PartialOrd for HostControllerMarker
impl PartialOrd for HostControllerMarker
Sourceimpl ProtocolMarker for HostControllerMarker
impl ProtocolMarker for HostControllerMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.bluetooth.affordances.HostController"
const DEBUG_NAME: &'static str = "fuchsia.bluetooth.affordances.HostController"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = HostControllerProxy
type Proxy = HostControllerProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = HostControllerRequestStream
type RequestStream = HostControllerRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = HostControllerSynchronousProxy
type SynchronousProxy = HostControllerSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for HostControllerMarker
impl Eq for HostControllerMarker
impl StructuralPartialEq for HostControllerMarker