HostControllerSynchronousProxy

Struct HostControllerSynchronousProxy 

pub struct HostControllerSynchronousProxy { /* private fields */ }

Implementations

Source

impl HostControllerSynchronousProxy

pub fn new(channel: Channel) -> Self

pub fn into_channel(self) -> Channel

pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<HostControllerEvent, Error>

Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.

pub fn get_hosts( &self, ___deadline: MonotonicInstant, ) -> Result<HostControllerGetHostsResult, Error>

Get all known hosts.

  • error Returns INTERNAL if the operation failed (check logs).
pub fn set_discoverability( &self, payload: &HostControllerSetDiscoverabilityRequest, ___deadline: MonotonicInstant, ) -> Result<HostControllerSetDiscoverabilityResult, Error>

Set discoverability state.

  • error Returns INTERNAL if the operation failed (check logs).
pub fn set_local_name( &self, payload: &HostControllerSetLocalNameRequest, ___deadline: MonotonicInstant, ) -> Result<HostControllerSetLocalNameResult, Error>

Set the active host’s local name.

  • request name Name to assign to the host.
  • error Returns INTERNAL if the operation failed (check logs).
pub fn start_pairing_delegate( &self, payload: &HostControllerStartPairingDelegateRequest, ___deadline: MonotonicInstant, ) -> Result<HostControllerStartPairingDelegateResult, Error>

Start a pairing delegate to respond to pairing procedures. Only one pairing delegate can be set at a time host-wide. Calling this while a delegate started by this method is already active will drop and overwrite the existing delegate. If this is called while a delegate started through other means is active, the new delegate will be closed immediately. Closing a pairing delegate after it is set aborts all ongoing pairing procedures without accepting and unsets the delegate.

If no pairing delegate is set, all pairings will be rejected even if the peer connection was initiated by the host.

  • error Returns INTERNAL if the operation failed (check logs).
pub fn stop_pairing_delegate( &self, ___deadline: MonotonicInstant, ) -> Result<HostControllerStopPairingDelegateResult, Error>

Stop a pairing delegate previously started by [StartPairingDelegate]. This will abort all ongoing pairing procedures without accepting and unsets the delegate.

This method can only stop a delegate started by [StartPairingDelegate], and will not stop a delegate started through other means.

  • error Returns INTERNAL if the operation failed (check logs).
pub fn set_device_class( &self, payload: &HostControllerSetDeviceClassRequest, ___deadline: MonotonicInstant, ) -> Result<HostControllerSetDeviceClassResult, Error>

Set the active host’s device class.

  • error Returns INTERNAL if the operation failed (check logs).