pub struct PeerControllerGetKnownPeersResponse {
pub peers: Option<Vec<Peer>>,
/* private fields */
}Fields
peers: Option<Vec<Peer>>Trait Implementations
Sourceimpl Clone for PeerControllerGetKnownPeersResponse
impl Clone for PeerControllerGetKnownPeersResponse
Sourcefn clone(&self) -> PeerControllerGetKnownPeersResponse
fn clone(&self) -> PeerControllerGetKnownPeersResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D> Decode<PeerControllerGetKnownPeersResponse, D> for PeerControllerGetKnownPeersResponsewhere
D: ResourceDialect,
impl<D> Decode<PeerControllerGetKnownPeersResponse, D> for PeerControllerGetKnownPeersResponsewhere
D: ResourceDialect,
Sourcefn new_empty() -> PeerControllerGetKnownPeersResponse
fn new_empty() -> PeerControllerGetKnownPeersResponse
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl Default for PeerControllerGetKnownPeersResponse
impl Default for PeerControllerGetKnownPeersResponse
Sourcefn default() -> PeerControllerGetKnownPeersResponse
fn default() -> PeerControllerGetKnownPeersResponse
Returns the “default value” for a type. Read more
Sourceimpl<D> Encode<PeerControllerGetKnownPeersResponse, D> for &PeerControllerGetKnownPeersResponsewhere
D: ResourceDialect,
impl<D> Encode<PeerControllerGetKnownPeersResponse, D> for &PeerControllerGetKnownPeersResponsewhere
D: ResourceDialect,
Sourceimpl PartialEq for PeerControllerGetKnownPeersResponse
impl PartialEq for PeerControllerGetKnownPeersResponse
Sourcefn eq(&self, other: &PeerControllerGetKnownPeersResponse) -> bool
fn eq(&self, other: &PeerControllerGetKnownPeersResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TypeMarker for PeerControllerGetKnownPeersResponse
impl TypeMarker for PeerControllerGetKnownPeersResponse
Sourcetype Owned = PeerControllerGetKnownPeersResponse
type Owned = PeerControllerGetKnownPeersResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for PeerControllerGetKnownPeersResponse
impl ValueTypeMarker for PeerControllerGetKnownPeersResponse
Sourcetype Borrowed<'a> = &'a PeerControllerGetKnownPeersResponse
type Borrowed<'a> = &'a PeerControllerGetKnownPeersResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<PeerControllerGetKnownPeersResponse as TypeMarker>::Owned,
) -> <PeerControllerGetKnownPeersResponse as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<PeerControllerGetKnownPeersResponse as TypeMarker>::Owned, ) -> <PeerControllerGetKnownPeersResponse as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Persistable for PeerControllerGetKnownPeersResponse
impl StructuralPartialEq for PeerControllerGetKnownPeersResponse