pub struct PeerControllerGetPeerIdResponder { /* private fields */ }Implementations
Sourceimpl PeerControllerGetPeerIdResponder
impl PeerControllerGetPeerIdResponder
Sourcepub fn send(
self,
result: Result<&PeerControllerGetPeerIdResponse, Error>,
) -> Result<(), Error>
pub fn send( self, result: Result<&PeerControllerGetPeerIdResponse, Error>, ) -> Result<(), Error>
Sends a response to the FIDL transaction.
Sets the channel to shutdown if an error occurs.
Sourcepub fn send_no_shutdown_on_err(
self,
result: Result<&PeerControllerGetPeerIdResponse, Error>,
) -> Result<(), Error>
pub fn send_no_shutdown_on_err( self, result: Result<&PeerControllerGetPeerIdResponse, Error>, ) -> Result<(), Error>
Similar to “send” but does not shutdown the channel if an error occurs.