pub struct PeripheralControllerMarker;Trait Implementations
Sourceimpl Clone for PeripheralControllerMarker
impl Clone for PeripheralControllerMarker
Sourcefn clone(&self) -> PeripheralControllerMarker
fn clone(&self) -> PeripheralControllerMarker
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PeripheralControllerMarker
impl Debug for PeripheralControllerMarker
Sourceimpl DiscoverableProtocolMarker for PeripheralControllerMarker
impl DiscoverableProtocolMarker for PeripheralControllerMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
Sourceimpl Hash for PeripheralControllerMarker
impl Hash for PeripheralControllerMarker
Sourceimpl Ord for PeripheralControllerMarker
impl Ord for PeripheralControllerMarker
Sourcefn cmp(&self, other: &PeripheralControllerMarker) -> Ordering
fn cmp(&self, other: &PeripheralControllerMarker) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for PeripheralControllerMarker
impl PartialOrd for PeripheralControllerMarker
Sourceimpl ProtocolMarker for PeripheralControllerMarker
impl ProtocolMarker for PeripheralControllerMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.bluetooth.affordances.PeripheralController"
const DEBUG_NAME: &'static str = "fuchsia.bluetooth.affordances.PeripheralController"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = PeripheralControllerProxy
type Proxy = PeripheralControllerProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = PeripheralControllerRequestStream
type RequestStream = PeripheralControllerRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = PeripheralControllerSynchronousProxy
type SynchronousProxy = PeripheralControllerSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for PeripheralControllerMarker
impl Eq for PeripheralControllerMarker
impl StructuralPartialEq for PeripheralControllerMarker